# Package dg_util 
v 0.0.15

Package dg_util consists of different interface of commonly used basic functions in development process to help reduce redoundancy and keep your codes clean. More features will be updated in future.
* Install: 

```bash
pip install dg_util
```

* Uninstall: 

```bash
pip uninstall dg_util
```

## Features
### Image Reprocessing
Crop face images with landmark.
1. crop_image
2. crop_image_from_path

### Face Parsing
Genreate face parsing with BiSeNet。
1. parsing_face
2. parsing_faces

### Rembg
Remove background.
1. bg.move